@@ -234,10 +234,13 @@ def plot_k2(kk, kk_many, frequencies_disp, frequencies_ft, f, data, data_project
     return 
 
 
-def plot1(freq,ZQS, labels):
+def plot1(freq,ZQS, labels, max_Z):
     pgf_with_latex["figure.figsize"] = figsize(1.4)[::-1]
     mpl.rcParams.update(pgf_with_latex)
     n = len(ZQS[0])-1
+    
+    if(max_Z > np.max(ZQS) or max_Z < 0.0):
+        max_Z = np.max(ZQS)
 
     fig, axs = plt.subplots(n, sharex=True, sharey=True, gridspec_kw={'hspace': 0})
     if not (type(axs) == np.ndarray):
@@ -246,7 +249,7 @@ def plot1(freq,ZQS, labels):
         axs[i].plot(freq,ZQS[:,0], ':', color='grey')
         axs[i].text(.75,.75,labels[i],fontsize=12,horizontalalignment='center', verticalalignment='center',transform=axs[i].transAxes)
         axs[i].plot(freq, ZQS[:,i+1])
-    
+    plt.ylim(top=max_Z)
     plt.yticks([])
 #    plt.ylabel('K-point DOS [kB T * ps]')
     plt.xlabel('Frequency [Thz]')
@@ -255,11 +258,14 @@ def plot1(freq,ZQS, labels):
     fig.savefig('plot1.pdf')
     return
 
-def plot2(freq,ZQS,modes, labels, freqs_from_disp):
+def plot2(freq,ZQS,modes, labels, freqs_from_disp, max_Z):
     pgf_with_latex["figure.figsize"] = figsize(1.4)[::-1]
     mpl.rcParams.update(pgf_with_latex)
     n_modes = len(modes)
     n_kpoints = len(ZQS[:,0,0])
+    
+    if(max_Z > np.max(ZQS) or max_Z < 0.0):
+        max_Z = np.max(ZQS)
 
     for n in range(n_kpoints): #iterating over the k points
         fig, axs = plt.subplots(n_modes, sharex=True, sharey=True, gridspec_kw={'hspace': 0})
@@ -273,14 +279,14 @@ def plot2(freq,ZQS,modes, labels, freqs_from_disp):
             axs[i].plot(freq, ZQS[n,:,mode+1])
 
         plt.yticks([])
+        plt.ylim(top=max_Z)
 #        plt.ylabel('K-point DOS [kB T * ps]')
         plt.xlabel('Frequency [Thz]')
-#        plt.tight_layout()
+        plt.tight_layout()
         plt.show() 
         fig.savefig('plot2_'+str(n)+'.pdf')
     return
 
-
 def plot3(Ts, frequencies, modes, labels):
     pgf_with_latex["figure.figsize"] = figsize(1.4)
     mpl.rcParams.update(pgf_with_latex)
