@@ -109,7 +109,7 @@ if(plot_type==1):
             
     ZQS = np.array(ZQS).T
     ZQS[:,0] = np.sum(ZQS[:,1::],axis=1)
-    plot.plot1(freq,ZQS, accepted_labels)
+    plot.plot1(freq,ZQS, accepted_labels, max_Z)
     
     
 if(plot_type==2): 
@@ -148,20 +148,25 @@ if(plot_type==2):
                     if(gaussian_smoothing != 0):
                         if(gaussian_smoothing < 0):
                             sig, mi = params[-1]/2.355, freq[int(len(freq)/2)]
-                    else:
-                        sig, mi = gaussian_smoothing, freq[int(len(freq)/2)]
+                        else:
+                            sig, mi = gaussian_smoothing, freq[int(len(freq)/2)]
                     if(sig==0):
                         sig = freq[1]-freq[0]
-    
+                    
                     gaussian = util.norm_gaussian(freq, mi, sig)                
                     # convolution_lorentzian = signal.fftconvolve(Z[:,n], plot.lorentzian(freq, freq[int(len(freq)/2)], params[1], params[2]), mode='same') / sum( plot.lorentzian(freq, *params))
                     convolution = signal.fftconvolve(Zq[:,n+1],gaussian, mode='same') / sum( gaussian)
                     Zq[:,n+1] = convolution
-                ZQS.append(Zq[:,:])
+                    
+                if(gaussian_smoothing < 0):
+                    sig = np.abs(gaussian_smoothing)
+                convolution_q = signal.fftconvolve(Zq[:,0],gaussian, mode='same') / sum( gaussian)
+                Zq[:,0] = convolution_q
+                ZQS.append(Zq)
                 count = count + 1
                 
     ZQS = np.array(ZQS)
-    plot.plot2(freq,ZQS, modes, accepted_labels, freqs_from_disp)
+    plot.plot2(freq,ZQS, modes, accepted_labels, freqs_from_disp, max_Z)
     
     
 if(plot_type==3):
